starcluster.image.S3ImageCreator

Package starcluster :: Module image :: Class S3ImageCreator |
[hide private]
[frames] | no frames]

# Class S3ImageCreator

source code

Class for creating a new instance-store AMI from a running instance

Instance Methods | [hide private]
__init__(self, easy_ec2, instance_id, key_location, aws_user_id, ec2_cert, ec2_private_key, bucket, image_name=`'``image``'`, description=None, kernel_id=None, ramdisk_id=None, remove_image_files=False, **kwargs) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__repr__(self) repr(x) | source code
create_image(self) | source code
_remove_image_files(self) | source code
_transfer_pem_files(self) copy pem files to /mnt on image host | source code
_bundle_image(self) | source code
_upload_image(self) | source code
_cleanup(self) | source code
_cleanup_pem_files(self) | source code
_register_image(self) | source code
Inherited from `ImageCreator`: `clean_private_data` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, easy_ec2, instance_id, key_location, aws_user_id, ec2_cert, ec2_private_key, bucket, image_name=`'``image``'`, description=None, kernel_id=None, ramdisk_id=None, remove_image_files=False, **kwargs) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)

### create_image(self) | source code
Decorators: `@print_timing`

### _bundle_image(self) | source code
Decorators: `@print_timing`

### _upload_image(self) | source code
Decorators: `@print_timing`